PyGlossary Web
Description: PyGlossary Web UI

##### Input file

##### Output file

#####

#####

ⓘ How to convert a dictionary?

1. Paste the full path to a dictionary file on your local file system in the Input file field.
2. Select input file format if not detected automatically.
3. Paste the full path to the converted file in the Output file field.
4. Select a target format to convert to
5. Click the Convert button and wait for the conversion to complete. For large files the operation can take several minutes.

## Conversion Options

Please enter valid JSON for custom conversion options.

Example config (See available options in plugins options reference):

+ Click for an example

    {
     "convertOptions": {
      "sortKeyName": "headword_lower:es_ES",
      "sortEncoding": "utf-8",
     },
     "readOptions": {
      "encoding": "utf-8",
      "example_color": "blue"
     },
     "writeOptions": {
      "resources": false
     }
    }